# PyPi Template

> A managed template repository for maintaining PyPi packages

[![Latest Version on PyPI](https://img.shields.io/pypi/v/pypi-template.svg)](https://pypi.python.org/pypi/pypi-template/)
[![Supported Implementations](https://img.shields.io/pypi/pyversions/pypi-template.svg)](https://pypi.python.org/pypi/pypi-template/)
[![Build Status](https://secure.travis-ci.org/christophevg/pypi-template.svg?branch=master)](http://travis-ci.org/christophevg/pypi-template)
[![Documentation Status](https://readthedocs.org/projects/pypi-template/badge/?version=latest)](https://pypi-template.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/christophevg/pypi-template/badge.svg?branch=master)](https://coveralls.io/github/christophevg/pypi-template?branch=master)
[![Built with PyPi Template](https://img.shields.io/badge/PyPi_Template-v0.1.3-blue.svg)](https://github.com/christophevg/pypi-template)



## Documentation

Visit [Read the Docs](https://pypi-template.readthedocs.org) for the full documentation, including overviews and several examples.


